@@ -1,10 +1,10 @@
 import datetime
 import warnings
 
-import pg8000
-
 import pytest
 
+import pg8000
+
 
 class PG8000TestException(Exception):
     pass
@@ -18,10 +18,8 @@ def test_py_value_fail(con, mocker):
     # Ensure that if types.py_value throws an exception, the original
     # exception is raised (PG8000TestException), and the connection is
     # still usable after the error.
-    mocker.patch.object(con, 'py_types')
-    con.py_types = {
-        datetime.time: (1083, raise_exception)
-    }
+    mocker.patch.object(con, "py_types")
+    con.py_types = {datetime.time: (1083, raise_exception)}
 
     with pytest.raises(PG8000TestException):
         c = con.cursor()
@@ -38,7 +36,7 @@ def test_no_data_error_recovery(con):
         with pytest.raises(pg8000.DatabaseError) as e:
             c = con.cursor()
             c.execute("DROP TABLE t1")
-        assert e.value.args[0]['C'] == '42P01'
+        assert e.value.args[0]["C"] == "42P01"
         con.rollback()
 
 
